@@ -38,7 +38,7 @@ def read_from_file():
             the_physical_condition[condition] = solution
 
 def write_to_file(solution_name,condition_name):
-    with open('wechat.txt','a')as file:
+    with open('APPLET.txt','a')as file:
         file.write('\n'+ solution_name + '/' + condition_name)
 
 the_physical_condition={}
